package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcSafeRequest;

/**
 * cmc安全要求Service接口
 * 
 * @author cmc
 * @date 2024-07-08
 */
public interface ICmcSafeRequestService 
{
    /**
     * 查询cmc安全要求
     * 
     * @param requestId cmc安全要求主键
     * @return cmc安全要求
     */
    public CmcSafeRequest selectCmcSafeRequestByRequestId(Integer requestId);

    /**
     * 查询cmc安全要求列表
     * 
     * @param cmcSafeRequest cmc安全要求
     * @return cmc安全要求集合
     */
    public List<CmcSafeRequest> selectCmcSafeRequestList(CmcSafeRequest cmcSafeRequest);

    /**
     * 新增cmc安全要求
     * 
     * @param cmcSafeRequest cmc安全要求
     * @return 结果
     */
    public int insertCmcSafeRequest(CmcSafeRequest cmcSafeRequest);

    /**
     * 修改cmc安全要求
     * 
     * @param cmcSafeRequest cmc安全要求
     * @return 结果
     */
    public int updateCmcSafeRequest(CmcSafeRequest cmcSafeRequest);

    /**
     * 批量删除cmc安全要求
     * 
     * @param requestIds 需要删除的cmc安全要求主键集合
     * @return 结果
     */
    public int deleteCmcSafeRequestByRequestIds(Integer[] requestIds);

    /**
     * 删除cmc安全要求信息
     * 
     * @param requestId cmc安全要求主键
     * @return 结果
     */
    public int deleteCmcSafeRequestByRequestId(Integer requestId);
}
